diff --git a/src/BlocksGUI/BlocksGUI_ExplodeDlg.cxx b/src/BlocksGUI/BlocksGUI_ExplodeDlg.cxx
index 962e76643..7e1cb2371 100644
--- a/src/BlocksGUI/BlocksGUI_ExplodeDlg.cxx
+++ b/src/BlocksGUI/BlocksGUI_ExplodeDlg.cxx
@@ -176,9 +176,9 @@ bool BlocksGUI_ExplodeDlg::ClickOnApply()
{
SUIT_Session::session()->activeApplication()->putInfo( tr( "" ) );
- // Explode all sub shapes
+ // Explode all sub-shapes
if ( isAllSubShapes() ) {
- // More than 30 subshapes : ask confirmation
+ // More than 30 sub-shapes : ask confirmation
if ( myNbBlocks > 30 ) {
if ( SUIT_MessageBox::warning( this,
tr( "GEOM_CONFIRM" ),
@@ -279,7 +279,7 @@ void BlocksGUI_ExplodeDlg::ValueChangedInSpinBox()
//=================================================================================
// function : SubShapeToggled()
-// purpose : Allow user selection of all or only selected sub shapes
+// purpose : Allow user selection of all or only selected sub-shapes
// : Called when 'myGrp1->CheckBox1' state change
//=================================================================================
void BlocksGUI_ExplodeDlg::SubShapeToggled()
diff --git a/src/EntityGUI/EntityGUI.h b/src/EntityGUI/EntityGUI.h
index 7c3cdf67f..65bcf6d0c 100644
--- a/src/EntityGUI/EntityGUI.h
+++ b/src/EntityGUI/EntityGUI.h
@@ -57,7 +57,7 @@ public :
void DisplaySimulationShape( const TopoDS_Shape&, const TopoDS_Shape& );
void EraseSimulationShape();
- // Methods for sub shapes explode
+ // Methods for sub-shapes explode
bool SObjectExist( const _PTR(SObject)&, const char* );
public:
diff --git a/src/EntityGUI/EntityGUI_SubShapeDlg.cxx b/src/EntityGUI/EntityGUI_SubShapeDlg.cxx
index e65655656..33b15d982 100644
--- a/src/EntityGUI/EntityGUI_SubShapeDlg.cxx
+++ b/src/EntityGUI/EntityGUI_SubShapeDlg.cxx
@@ -131,7 +131,7 @@ void EntityGUI_SubShapeDlg::Init()
myWithShape = true;
- /* type for sub shape selection */
+ /* type for sub-shape selection */
GroupPoints->ComboBox1->insertItem(GroupPoints->ComboBox1->count(), "Compound");
GroupPoints->ComboBox1->insertItem(GroupPoints->ComboBox1->count(), "Compsolid");
GroupPoints->ComboBox1->insertItem(GroupPoints->ComboBox1->count(), "Solid");
@@ -213,10 +213,10 @@ void EntityGUI_SubShapeDlg::ClickOnOk()
SUIT_Session::session()->activeApplication()->putInfo("");
- /* Explode all sub shapes */
+ /* Explode all sub-shapes */
bool isOk = true;
if (isAllSubShapes()) {
- /* More than 30 subshapes : ask confirmation */
+ /* More than 30 sub-shapes : ask confirmation */
unsigned int nb = NumberOfSubShapes(myShape, shapeType());
if (nb > 30) {
const QString caption = tr("GEOM_CONFIRM");
@@ -244,9 +244,9 @@ bool EntityGUI_SubShapeDlg::ClickOnApply()
{
SUIT_Session::session()->activeApplication()->putInfo("");
- /* Explode all sub shapes */
+ /* Explode all sub-shapes */
if (isAllSubShapes()) {
- /* More than 30 subshapes : ask confirmation */
+ /* More than 30 sub-shapes : ask confirmation */
unsigned int nb = NumberOfSubShapes(myShape, shapeType());
if (nb > 30) {
const QString caption = tr("GEOM_CONFIRM");
@@ -419,7 +419,7 @@ void EntityGUI_SubShapeDlg::ResetStateOfDialog()
if (myWithShape)
count = count - 1;
- /* type for sub shape selection */
+ /* type for sub-shape selection */
GroupPoints->ComboBox1->clear();
GroupPoints->ComboBox1->insertItem(GroupPoints->ComboBox1->count(), "Compound");
GroupPoints->ComboBox1->insertItem(GroupPoints->ComboBox1->count(), "Compsolid");
@@ -443,7 +443,7 @@ void EntityGUI_SubShapeDlg::ResetStateOfDialog()
//=================================================================================
// function : SubShapeToggled()
-// purpose : Allow user selection of all or only selected sub shapes
+// purpose : Allow user selection of all or only selected sub-shapes
// : Called when 'CheckButton1' state change
//=================================================================================
void EntityGUI_SubShapeDlg::SubShapeToggled()
@@ -461,7 +461,7 @@ void EntityGUI_SubShapeDlg::SubShapeToggled()
//=================================================================================
void EntityGUI_SubShapeDlg::ComboTextChanged()
{
- /* Select sub shapes mode not checked */
+ /* Select sub-shapes mode not checked */
updateButtonState();
SubShapeToggled();
}
diff --git a/src/GEOM/GEOM_Engine.cxx b/src/GEOM/GEOM_Engine.cxx
index 53addff1f..28393c39b 100644
--- a/src/GEOM/GEOM_Engine.cxx
+++ b/src/GEOM/GEOM_Engine.cxx
@@ -413,7 +413,7 @@ Handle(GEOM_Object) GEOM_Engine::AddSubShape(Handle(GEOM_Object) theMainShape,
if (_objects.IsBound(anID)) _objects.UnBind(anID);
_objects.Bind(anID, anObject);
- // Put this subshape in the list of subshapes of theMainShape
+ // Put this sub-shape in the list of sub-shapes of theMainShape
aMainShape->AddSubShapeReference(aFunction);
GEOM::TPythonDump pd (aFunction);
@@ -449,7 +449,7 @@ bool GEOM_Engine::RemoveObject(Handle(GEOM_Object) theObject)
TCollection_AsciiString anID = BuildIDFromObject(theObject);
if (_objects.IsBound(anID)) _objects.UnBind(anID);
- // If subshape, remove it from the list of subshapes of its main shape
+ // If sub-shape, remove it from the list of sub-shapes of its main shape
if (!theObject->IsMainShape()) {
Handle(GEOM_Function) aFunction = theObject->GetFunction(1);
GEOM_ISubShape aSSI (aFunction);
diff --git a/src/GEOM/GEOM_Engine.hxx b/src/GEOM/GEOM_Engine.hxx
index 70152563c..5ff84364f 100644
--- a/src/GEOM/GEOM_Engine.hxx
+++ b/src/GEOM/GEOM_Engine.hxx
@@ -141,7 +141,7 @@ class GEOM_Engine
//Applies an Redo to document with ID = theDocID
Standard_EXPORT void Redo(int theDocID);
- //Adds a new sub shape object of the MainShape object
+ //Adds a new sub-shape object of the MainShape object
Standard_EXPORT Handle(GEOM_Object) AddSubShape(Handle(GEOM_Object) theMainShape,
Handle(TColStd_HArray1OfInteger) theIndices,
bool isStandaloneOperation = false);
diff --git a/src/GEOM/GEOM_Function.cxx b/src/GEOM/GEOM_Function.cxx
index 2dc313318..cc06c38f6 100644
--- a/src/GEOM/GEOM_Function.cxx
+++ b/src/GEOM/GEOM_Function.cxx
@@ -214,7 +214,7 @@ TopoDS_Shape GEOM_Function::GetValue()
#endif
GEOM_Solver aSolver(GEOM_Engine::GetEngine());
if (!aSolver.ComputeFunction(this)) {
- MESSAGE("GEOM_Object::GetValue Error : Can't build a sub shape");
+ MESSAGE("GEOM_Object::GetValue Error : Can't build a sub-shape");
return aShape;
}
}
diff --git a/src/GEOM/GEOM_Object.cxx b/src/GEOM/GEOM_Object.cxx
index cb20eed79..604543026 100644
--- a/src/GEOM/GEOM_Object.cxx
+++ b/src/GEOM/GEOM_Object.cxx
@@ -545,7 +545,7 @@ bool GEOM_Object::IsMainShape()
Handle(GEOM_Function) GEOM_Object::AddFunction(const Standard_GUID& theGUID, int theFunctionType)
{
Standard_Integer nb = GetNbFunctions();
- if(nb == 1 && theGUID == GetSubShapeID()) return NULL; //It's impossible to add a function to sub shape
+ if(nb == 1 && theGUID == GetSubShapeID()) return NULL; //It's impossible to add a function to sub-shape
nb++;
TDF_Label aChild = FUNCTION_LABEL(nb);
diff --git a/src/GEOM/GEOM_Object.hxx b/src/GEOM/GEOM_Object.hxx
index 77789a17f..6a4dd55fb 100644
--- a/src/GEOM/GEOM_Object.hxx
+++ b/src/GEOM/GEOM_Object.hxx
@@ -178,7 +178,7 @@ class GEOM_Object : public MMgt_TShared
//Returns a GEOM_Object common GUID
Standard_EXPORT static const Standard_GUID& GetObjectID();
- //Returns a GUID associated with a sub shape object
+ //Returns a GUID associated with a sub-shape object
Standard_EXPORT static const Standard_GUID& GetSubShapeID();
//###########################################################
@@ -257,10 +257,10 @@ class GEOM_Object : public MMgt_TShared
Standard_EXPORT TCollection_AsciiString GetParameters() const;
//###########################################################
- // Sub shape methods
+ // Sub-shape methods
//###########################################################
- //Returns false if the object is a sub shape of another object
+ //Returns false if the object is a sub-shape of another object
Standard_EXPORT bool IsMainShape();
//###########################################################
diff --git a/src/GEOM/GEOM_SubShapeDriver.cxx b/src/GEOM/GEOM_SubShapeDriver.cxx
index b58d77930..c9b207f1f 100644
--- a/src/GEOM/GEOM_SubShapeDriver.cxx
+++ b/src/GEOM/GEOM_SubShapeDriver.cxx
@@ -70,7 +70,7 @@ Standard_Integer GEOM_SubShapeDriver::Execute(TFunction_Logbook& log) const
TopoDS_Compound aCompound;
TopoDS_Shape aShape;
- if (anIndices->Length() == 1 && anIndices->Value(1) == -1) { //The empty subshape
+ if (anIndices->Length() == 1 && anIndices->Value(1) == -1) { //The empty sub-shape
B.MakeCompound(aCompound);
aShape = aCompound;
}
diff --git a/src/GEOMAlgo/GEOMAlgo_BuilderShape.cdl b/src/GEOMAlgo/GEOMAlgo_BuilderShape.cdl
index e54d5ac1d..b19cc30eb 100755
--- a/src/GEOMAlgo/GEOMAlgo_BuilderShape.cdl
+++ b/src/GEOMAlgo/GEOMAlgo_BuilderShape.cdl
@@ -77,17 +77,17 @@ is
is virtual;
HasDeleted (me)
- ---Purpose: Returns true if the at least one shape(or subshape)
+ ---Purpose: Returns true if the at least one shape(or sub-shape)
-- of arguments has been deleted.
returns Boolean from Standard;
HasGenerated (me)
- ---Purpose: Returns true if the at least one shape(or subshape)
+ ---Purpose: Returns true if the at least one shape(or sub-shape)
-- of arguments has generated shapes.
returns Boolean from Standard;
HasModified (me)
- ---Purpose: Returns true if the at least one shape(or subshape)
+ ---Purpose: Returns true if the at least one shape(or sub-shape)
-- of arguments has modified shapes.
returns Boolean from Standard;
diff --git a/src/GEOMAlgo/GEOMAlgo_BuilderShape.hxx b/src/GEOMAlgo/GEOMAlgo_BuilderShape.hxx
index e6e312bae..75c87f10f 100644
--- a/src/GEOMAlgo/GEOMAlgo_BuilderShape.hxx
+++ b/src/GEOMAlgo/GEOMAlgo_BuilderShape.hxx
@@ -87,15 +87,15 @@ Standard_EXPORT virtual const TopTools_ListOfShape& Modified(const TopoDS_Shape&
//! Returns true if the shape theS has been deleted.
Standard_EXPORT virtual Standard_Boolean IsDeleted(const TopoDS_Shape& theS) ;
-//! Returns true if the at least one shape(or subshape)
+//! Returns true if the at least one shape(or sub-shape)
//! of arguments has been deleted.
Standard_EXPORT Standard_Boolean HasDeleted() const;
-//! Returns true if the at least one shape(or subshape)
+//! Returns true if the at least one shape(or sub-shape)
//! of arguments has generated shapes.
Standard_EXPORT Standard_Boolean HasGenerated() const;
-//! Returns true if the at least one shape(or subshape)
+//! Returns true if the at least one shape(or sub-shape)
//! of arguments has modified shapes.
Standard_EXPORT Standard_Boolean HasModified() const;
diff --git a/src/GEOMAlgo/GEOMAlgo_FinderShapeOn.cxx b/src/GEOMAlgo/GEOMAlgo_FinderShapeOn.cxx
index c0f0ac711..ee472806e 100644
--- a/src/GEOMAlgo/GEOMAlgo_FinderShapeOn.cxx
+++ b/src/GEOMAlgo/GEOMAlgo_FinderShapeOn.cxx
@@ -230,7 +230,7 @@ void GEOMAlgo_FinderShapeOn::FindVertices()
TopExp::MapShapes(myShape, myShapeType, aM);
aNb=aM.Extent();
if (!aNb) {
- myWarningStatus=10; // No found subshapes of type myShapeType
+ myWarningStatus=10; // No found sub-shapes of type myShapeType
return;
}
//
@@ -259,7 +259,7 @@ void GEOMAlgo_FinderShapeOn::Find()
//
aNb=aM.Extent();
if (!aNb) {
- myWarningStatus=10; // No found subshapes of type myShapeType
+ myWarningStatus=10; // No found sub-shapes of type myShapeType
return;
}
//
@@ -339,7 +339,7 @@ void GEOMAlgo_FinderShapeOn::Find(const TopoDS_Shape& aS)
pSS=&aSLS;
break;
default:
- myErrorStatus=12; // unallowed subshape type
+ myErrorStatus=12; // unallowed sub-shape type
return;
}
//
@@ -480,7 +480,7 @@ void GEOMAlgo_FinderShapeOn::CheckData()
myShapeType==TopAbs_EDGE ||
myShapeType==TopAbs_FACE ||
myShapeType==TopAbs_SOLID)) {
- myErrorStatus=12; // unallowed subshape type
+ myErrorStatus=12; // unallowed sub-shape type
return;
}
//
@@ -599,7 +599,7 @@ bool GEOMAlgo_FinderShapeOn::BuildTriangulation (const TopoDS_Shape& theShape)
//
// 10 -mySurface=NULL
// 11 -myShape=NULL
-// 12 -unallowed type of subshapes
+// 12 -unallowed type of sub-shapes
// 13 -unallowed state
// 20 -can not build the face
// 30 -wrong args are used for DSFiller
@@ -609,4 +609,4 @@ bool GEOMAlgo_FinderShapeOn::BuildTriangulation (const TopoDS_Shape& theShape)
//
// myWarningStatus
//
-// 10 -subshapes of type myShapeType can not be fond in myShape
+// 10 - sub-shapes of type myShapeType can not be fond in myShape
diff --git a/src/GEOMAlgo/GEOMAlgo_FinderShapeOn1.cxx b/src/GEOMAlgo/GEOMAlgo_FinderShapeOn1.cxx
index fe0a48d5d..3396d9320 100644
--- a/src/GEOMAlgo/GEOMAlgo_FinderShapeOn1.cxx
+++ b/src/GEOMAlgo/GEOMAlgo_FinderShapeOn1.cxx
@@ -790,7 +790,7 @@ void GEOMAlgo_FinderShapeOn1::CheckData()
myShapeType==TopAbs_EDGE ||
myShapeType==TopAbs_FACE ||
myShapeType==TopAbs_SOLID)) {
- myErrorStatus=12; // unallowed subshape type
+ myErrorStatus=12; // unallowed sub-shape type
return;
}
//
@@ -829,7 +829,7 @@ TopAbs_State GEOMAlgo_FinderShapeOn1::GetPointState(const gp_Pnt& aP)
//
// 10 -mySurface=NULL
// 11 -myShape=NULL
-// 12 -unallowed type of subshapes
+// 12 -unallowed type of sub-shapes
// 13 -unallowed state
// 14 -unallowed surface type
// 15 -unallowed surface type
diff --git a/src/GEOMAlgo/GEOMAlgo_FinderShapeOn2.cxx b/src/GEOMAlgo/GEOMAlgo_FinderShapeOn2.cxx
index 861f06c8f..c919c9c77 100644
--- a/src/GEOMAlgo/GEOMAlgo_FinderShapeOn2.cxx
+++ b/src/GEOMAlgo/GEOMAlgo_FinderShapeOn2.cxx
@@ -289,7 +289,7 @@
myShapeType==TopAbs_EDGE ||
myShapeType==TopAbs_FACE ||
myShapeType==TopAbs_SOLID)) {
- myErrorStatus=12; // unallowed subshape type
+ myErrorStatus=12; // unallowed sub-shape type
return;
}
//
@@ -833,7 +833,7 @@
//
// 10 -myClsf=NULL
// 11 -myShape=NULL
-// 12 -unallowed type of subshapes
+// 12 -unallowed type of sub-shapes
// 13 -unallowed state
// 15 -unallowed surface type
// 20- no triangulation found
diff --git a/src/GEOMAlgo/GEOMAlgo_Gluer.cxx b/src/GEOMAlgo/GEOMAlgo_Gluer.cxx
index 29b2a3f2f..a35a31d11 100755
--- a/src/GEOMAlgo/GEOMAlgo_Gluer.cxx
+++ b/src/GEOMAlgo/GEOMAlgo_Gluer.cxx
@@ -654,7 +654,7 @@ void GEOMAlgo_Gluer::MakeShapes(const TopAbs_ShapeEnum aType)
//
bHasNewSubShape=Standard_True;
// prevent creation of a new shape if there are not
- // new subshapes of aSS among the originals
+ // new sub-shapes of aSS among the originals
if (aNbSDF==1) {
bHasNewSubShape=HasNewSubShape(aS1);
if (!bHasNewSubShape) {
diff --git a/src/GEOMAlgo/GEOMAlgo_Gluer2_3.cxx b/src/GEOMAlgo/GEOMAlgo_Gluer2_3.cxx
index d39bb4f90..06aaf308d 100644
--- a/src/GEOMAlgo/GEOMAlgo_Gluer2_3.cxx
+++ b/src/GEOMAlgo/GEOMAlgo_Gluer2_3.cxx
@@ -235,7 +235,7 @@ void GEOMAlgo_Gluer2::TreatPair(const NMTTools_CoupleOfShape& aCS,
// 2. Append the pair to the aLCS
aLCS.Append(aCS);
//
- // 3. Treatment the subshapes of the pair
+ // 3. Treatment the sub-shapes of the pair
aType=aS1.ShapeType();
if (aType==TopAbs_VERTEX) {
return;
diff --git a/src/GEOMBase/GEOMBase.cxx b/src/GEOMBase/GEOMBase.cxx
index 038b05590..e9cab04ab 100644
--- a/src/GEOMBase/GEOMBase.cxx
+++ b/src/GEOMBase/GEOMBase.cxx
@@ -85,7 +85,7 @@ TopoDS_Shape GEOMBase::GetShapeFromIOR( const QString& IOR )
//=====================================================================================
// function : GetIndex()
-// purpose : Get the index of a sub shape in a main shape : index start at 1
+// purpose : Get the index of a sub-shape in a main shape : index start at 1
//=====================================================================================
int GEOMBase::GetIndex( const TopoDS_Shape& subshape, const TopoDS_Shape& shape )
{
diff --git a/src/GEOMBase/GEOMBase_Helper.cxx b/src/GEOMBase/GEOMBase_Helper.cxx
index 71355da4d..50c5c46e6 100755
--- a/src/GEOMBase/GEOMBase_Helper.cxx
+++ b/src/GEOMBase/GEOMBase_Helper.cxx
@@ -448,7 +448,7 @@ void GEOMBase_Helper::activate( const int theType )
//================================================================
// Function : localSelection
-// Purpose : Activate selection of subshapes in accordance with mode
+// Purpose : Activate selection of sub-shapes in accordance with mode
// theMode is from TopAbs_ShapeEnum
//================================================================
void GEOMBase_Helper::localSelection( const ObjectList& theObjs, const int theMode )
@@ -472,7 +472,7 @@ void GEOMBase_Helper::localSelection( const ObjectList& theObjs, const int theMo
//================================================================
// Function : localSelection
-// Purpose : Activate selection of subshapes in accordance with mode
+// Purpose : Activate selection of sub-shapes in accordance with mode
// theMode is from TopAbs_ShapeEnum
//================================================================
void GEOMBase_Helper::localSelection( GEOM::GEOM_Object_ptr obj, const int mode )
@@ -491,7 +491,7 @@ void GEOMBase_Helper::localSelection( GEOM::GEOM_Object_ptr obj, const int mode
//================================================================
// Function : globalSelection
-// Purpose : Activate selection of subshapes. Set selection filters
+// Purpose : Activate selection of sub-shapes. Set selection filters
// in accordance with mode. theMode is from GEOMImpl_Types
//================================================================
void GEOMBase_Helper::globalSelection( const int theMode, const bool update )
@@ -501,7 +501,7 @@ void GEOMBase_Helper::globalSelection( const int theMode, const bool update )
//================================================================
// Function : globalSelection
-// Purpose : Activate selection of subshapes. Set selection filters
+// Purpose : Activate selection of sub-shapes. Set selection filters
// in accordance with mode. theMode is from GEOMImpl_Types
//================================================================
void GEOMBase_Helper::globalSelection( const TColStd_MapOfInteger& theModes,
@@ -512,7 +512,7 @@ void GEOMBase_Helper::globalSelection( const TColStd_MapOfInteger& theModes,
//================================================================
// Function : globalSelection
-// Purpose : Activate selection of subshapes. Set selection filters
+// Purpose : Activate selection of sub-shapes. Set selection filters
// in accordance with mode. theMode is from GEOMImpl_Types
//================================================================
void GEOMBase_Helper::globalSelection( const TColStd_MapOfInteger& theModes,
@@ -844,7 +844,7 @@ bool GEOMBase_Helper::onAccept( const bool publish, const bool useTransaction )
showError();
}
else {
- addSubshapesToStudy(); // add Subshapes if local selection
+ addSubshapesToStudy(); // add Sub-shapes if local selection
const int nbObjs = objects.size();
QStringList anEntryList;
int aNumber = 1;
@@ -1145,7 +1145,7 @@ GEOM::GEOM_Object_ptr GEOMBase_Helper::findObjectInFather( GEOM::GEOM_Object_ptr
//================================================================
// Function : addSubshapesToStudy
-// Purpose : Virtual method to add subshapes if needs
+// Purpose : Virtual method to add sub-shapes if needs
//================================================================
void GEOMBase_Helper::addSubshapesToStudy()
{
diff --git a/src/GEOMImpl/BRepBuilderAPI_ModifyShape_21423.hxx b/src/GEOMImpl/BRepBuilderAPI_ModifyShape_21423.hxx
index b631347f2..d67e70e1b 100644
--- a/src/GEOMImpl/BRepBuilderAPI_ModifyShape_21423.hxx
+++ b/src/GEOMImpl/BRepBuilderAPI_ModifyShape_21423.hxx
@@ -67,10 +67,10 @@ public:
//! .
Standard_EXPORT virtual const TopTools_ListOfShape& Modified(const TopoDS_Shape& S) ;
//! Returns the modified shape corresponding to .
-//! S can correspond to the entire initial shape or to its subshape.
+//! S can correspond to the entire initial shape or to its sub-shape.
//! Exceptions
//! Standard_NoSuchObject if S is not the initial shape or
-//! a subshape of the initial shape to which the
+//! a sub-shape of the initial shape to which the
//! transformation has been applied. Raises NoSuchObject from Standard
//! if S is not the initial shape or a sub-shape
//! of the initial shape.
diff --git a/src/GEOMImpl/GEOMImpl_IGroupOperations.cxx b/src/GEOMImpl/GEOMImpl_IGroupOperations.cxx
index 09f7a400e..5c6619e41 100644
--- a/src/GEOMImpl/GEOMImpl_IGroupOperations.cxx
+++ b/src/GEOMImpl/GEOMImpl_IGroupOperations.cxx
@@ -89,7 +89,7 @@ Handle(GEOM_Object) GEOMImpl_IGroupOperations::CreateGroup
//Set a GROUP type
aGroup->SetType(GEOM_GROUP);
- //Set a sub shape type
+ //Set a sub-shape type
TDF_Label aFreeLabel = aGroup->GetFreeLabel();
TDataStd_Integer::Set(aFreeLabel, (Standard_Integer)theShapeType);
diff --git a/src/GEOMImpl/GEOMImpl_IHealingOperations.cxx b/src/GEOMImpl/GEOMImpl_IHealingOperations.cxx
index 265a35f6c..5c6ea1f38 100644
--- a/src/GEOMImpl/GEOMImpl_IHealingOperations.cxx
+++ b/src/GEOMImpl/GEOMImpl_IHealingOperations.cxx
@@ -813,7 +813,7 @@ Handle(GEOM_Object) GEOMImpl_IHealingOperations::ChangeOrientation (Handle(GEOM_
return NULL;
if (!theObject->IsMainShape()) {
- SetErrorCode("Sub shape cannot be transformed - need to create a copy");
+ SetErrorCode("Sub-shape cannot be transformed - need to create a copy");
return NULL;
}
diff --git a/src/GEOMImpl/GEOMImpl_IMeasureOperations.cxx b/src/GEOMImpl/GEOMImpl_IMeasureOperations.cxx
index 33d7b59b7..1559dd62b 100644
--- a/src/GEOMImpl/GEOMImpl_IMeasureOperations.cxx
+++ b/src/GEOMImpl/GEOMImpl_IMeasureOperations.cxx
@@ -2629,7 +2629,7 @@ void GEOMImpl_IMeasureOperations::StructuralDump (const BRepCheck_Analyzer& theA
}
count = NbProblems->Value((Standard_Integer)BRepCheck_SubshapeNotInShape);
if (count > 0) {
- theDump += " Subshape not in Shape .................... ";
+ theDump += " Sub-shape not in Shape .................... ";
theDump += TCollection_AsciiString(count) + "\n";
}
count = NbProblems->Value((Standard_Integer)BRepCheck_BadOrientation);
@@ -2639,7 +2639,7 @@ void GEOMImpl_IMeasureOperations::StructuralDump (const BRepCheck_Analyzer& theA
}
count = NbProblems->Value((Standard_Integer)BRepCheck_BadOrientationOfSubshape);
if (count > 0) {
- theDump += " Bad Orientation of Subshape .............. ";
+ theDump += " Bad Orientation of Sub-shape .............. ";
theDump += TCollection_AsciiString(count) + "\n";
}
count = NbProblems->Value((Standard_Integer)BRepCheck_CheckFail);
diff --git a/src/GEOMImpl/GEOMImpl_IShapesOperations.cxx b/src/GEOMImpl/GEOMImpl_IShapesOperations.cxx
index bc1b8cbce..cd98b179f 100644
--- a/src/GEOMImpl/GEOMImpl_IShapesOperations.cxx
+++ b/src/GEOMImpl/GEOMImpl_IShapesOperations.cxx
@@ -1298,7 +1298,7 @@ Handle(TColStd_HSequenceOfTransient) GEOMImpl_IShapesOperations::MakeExplode
// on the main shape for each being calculated sub-shape separately.
aFunction->SetValue(aValue);
- // Put this subshape in the list of subshapes of theMainShape
+ // Put this subshape in the list of sub-shapes of theMainShape
aMainShape->AddSubShapeReference(aFunction);
}
@@ -1512,7 +1512,7 @@ Handle(TColStd_HSequenceOfTransient) GEOMImpl_IShapesOperations::MakeSubShapes
// on the main shape for each being calculated sub-shape separately.
aFunction->SetValue(aValue);
- // Put this subshape in the list of subshapes of theMainShape
+ // Put this sub-shape in the list of sub-shapes of theMainShape
aMainShape->AddSubShapeReference(aFunction);
aSeq->Append(anObj);
@@ -2183,12 +2183,12 @@ Handle(Geom_Surface) GEOMImpl_IShapesOperations::makeCylinder(const TopoDS_Shape
//=======================================================================
//function : getShapesOnBoxIDs
/*!
- * \brief Find IDs of subshapes complying with given status about surface
- * \param theBox - the box to check state of subshapes against
+ * \brief Find IDs of sub-shapes complying with given status about surface
+ * \param theBox - the box to check state of sub-shapes against
* \param theShape - the shape to explore
- * \param theShapeType - type of subshape of theShape
+ * \param theShapeType - type of sub-shape of theShape
* \param theState - required state
- * \retval Handle(TColStd_HSequenceOfInteger) - IDs of found subshapes
+ * \retval Handle(TColStd_HSequenceOfInteger) - IDs of found sub-shapes
*/
//=======================================================================
Handle(TColStd_HSequenceOfInteger)
@@ -2264,12 +2264,12 @@ Handle(TColStd_HSequenceOfInteger)
//=======================================================================
//function : GetShapesOnBoxIDs
/*!
- * \brief Find subshapes complying with given status about surface
- * \param theBox - the box to check state of subshapes against
+ * \brief Find sub-shapes complying with given status about surface
+ * \param theBox - the box to check state of sub-shapes against
* \param theShape - the shape to explore
- * \param theShapeType - type of subshape of theShape
+ * \param theShapeType - type of sub-shape of theShape
* \param theState - required state
- * \retval Handle(TColStd_HSequenceOfInteger) - IDs of found subshapes
+ * \retval Handle(TColStd_HSequenceOfInteger) - IDs of found sub-shapes
*/
//=======================================================================
Handle(TColStd_HSequenceOfInteger)
@@ -2278,7 +2278,7 @@ Handle(TColStd_HSequenceOfInteger)
const Standard_Integer theShapeType,
GEOMAlgo_State theState)
{
- // Find subshapes ids
+ // Find sub-shapes ids
Handle(TColStd_HSequenceOfInteger) aSeqOfIDs =
getShapesOnBoxIDs (theBox, theShape, theShapeType, theState);
if ( aSeqOfIDs.IsNull() || aSeqOfIDs->Length() == 0 )
@@ -2302,12 +2302,12 @@ Handle(TColStd_HSequenceOfInteger)
//=======================================================================
//function : GetShapesOnBox
/*!
- * \brief Find subshapes complying with given status about surface
- * \param theBox - the box to check state of subshapes against
+ * \brief Find sub-shapes complying with given status about surface
+ * \param theBox - the box to check state of sub-shapes against
* \param theShape - the shape to explore
- * \param theShapeType - type of subshape of theShape
+ * \param theShapeType - type of sub-shape of theShape
* \param theState - required state
- * \retval Handle(TColStd_HSequenceOfTransient) - found subshapes
+ * \retval Handle(TColStd_HSequenceOfTransient) - found sub-shapes
*/
//=======================================================================
Handle(TColStd_HSequenceOfTransient)
@@ -2316,7 +2316,7 @@ Handle(TColStd_HSequenceOfTransient)
const Standard_Integer theShapeType,
GEOMAlgo_State theState)
{
- // Find subshapes ids
+ // Find sub-shapes ids
Handle(TColStd_HSequenceOfInteger) aSeqOfIDs =
getShapesOnBoxIDs (theBox, theShape, theShapeType, theState);
if ( aSeqOfIDs.IsNull() || aSeqOfIDs->Length() == 0 )
@@ -2348,12 +2348,12 @@ Handle(TColStd_HSequenceOfTransient)
//=======================================================================
//function : getShapesOnShapeIDs
/*!
- * \brief Find IDs of subshapes complying with given status about surface
- * \param theCheckShape - the shape to check state of subshapes against
+ * \brief Find IDs of sub-shapes complying with given status about surface
+ * \param theCheckShape - the shape to check state of sub-shapes against
* \param theShape - the shape to explore
- * \param theShapeType - type of subshape of theShape
+ * \param theShapeType - type of sub-shape of theShape
* \param theState - required state
- * \retval Handle(TColStd_HSequenceOfInteger) - IDs of found subshapes
+ * \retval Handle(TColStd_HSequenceOfInteger) - IDs of found sub-shapes
*/
//=======================================================================
Handle(TColStd_HSequenceOfInteger)
@@ -2435,12 +2435,12 @@ Handle(TColStd_HSequenceOfInteger)
//=======================================================================
//function : GetShapesOnShapeIDs
/*!
- * \brief Find subshapes complying with given status about surface
- * \param theCheckShape - the shape to check state of subshapes against
+ * \brief Find sub-shapes complying with given status about surface
+ * \param theCheckShape - the shape to check state of sub-shapes against
* \param theShape - the shape to explore
- * \param theShapeType - type of subshape of theShape
+ * \param theShapeType - type of sub-shape of theShape
* \param theState - required state
- * \retval Handle(TColStd_HSequenceOfInteger) - IDs of found subshapes
+ * \retval Handle(TColStd_HSequenceOfInteger) - IDs of found sub-shapes
*/
//=======================================================================
Handle(TColStd_HSequenceOfInteger)
@@ -2475,12 +2475,12 @@ Handle(TColStd_HSequenceOfInteger)
//=======================================================================
//function : GetShapesOnShape
/*!
- * \brief Find subshapes complying with given status about surface
- * \param theCheckShape - the shape to check state of subshapes against
+ * \brief Find sub-shapes complying with given status about surface
+ * \param theCheckShape - the shape to check state of sub-shapes against
* \param theShape - the shape to explore
- * \param theShapeType - type of subshape of theShape
+ * \param theShapeType - type of sub-shape of theShape
* \param theState - required state
- * \retval Handle(TColStd_HSequenceOfTransient) - found subshapes
+ * \retval Handle(TColStd_HSequenceOfTransient) - found sub-shapes
*/
//=======================================================================
Handle(TColStd_HSequenceOfTransient)
@@ -2573,12 +2573,12 @@ Handle(GEOM_Object) GEOMImpl_IShapesOperations::GetShapesOnShapeAsCompound
//=======================================================================
//function : getShapesOnSurfaceIDs
/*!
- * \brief Find IDs of subshapes complying with given status about surface
- * \param theSurface - the surface to check state of subshapes against
+ * \brief Find IDs of sub-shapes complying with given status about surface
+ * \param theSurface - the surface to check state of sub-shapes against
* \param theShape - the shape to explore
- * \param theShapeType - type of subshape of theShape
+ * \param theShapeType - type of sub-shape of theShape
* \param theState - required state
- * \retval Handle(TColStd_HSequenceOfInteger) - IDs of found subshapes
+ * \retval Handle(TColStd_HSequenceOfInteger) - IDs of found sub-shapes
*/
//=======================================================================
Handle(TColStd_HSequenceOfInteger)
@@ -2716,13 +2716,13 @@ Handle(TColStd_HSequenceOfTransient) GEOMImpl_IShapesOperations::
//=======================================================================
//function : getShapesOnSurface
/*!
- * \brief Find subshapes complying with given status about surface
- * \param theSurface - the surface to check state of subshapes against
+ * \brief Find sub-shapes complying with given status about surface
+ * \param theSurface - the surface to check state of sub-shapes against
* \param theShape - the shape to explore
- * \param theShapeType - type of subshape of theShape
+ * \param theShapeType - type of sub-shape of theShape
* \param theState - required state
* \param theShapeEntries - outgoing entries like "entry1, entry2, ..."
- * \retval Handle(TColStd_HSequenceOfInteger) - IDs of found subshapes
+ * \retval Handle(TColStd_HSequenceOfInteger) - IDs of found sub-shapes
*/
//=======================================================================
Handle(TColStd_HSequenceOfTransient)
@@ -2732,7 +2732,7 @@ Handle(TColStd_HSequenceOfTransient)
GEOMAlgo_State theState,
TCollection_AsciiString & theShapeEntries)
{
- // Find subshapes ids
+ // Find sub-shapes ids
Handle(TColStd_HSequenceOfInteger) aSeqOfIDs =
getShapesOnSurfaceIDs (theSurface, theShape->GetValue(), theShapeType, theState);
if ( aSeqOfIDs.IsNull() || aSeqOfIDs->Length() == 0 )
@@ -3318,15 +3318,15 @@ Handle(TColStd_HSequenceOfInteger) GEOMImpl_IShapesOperations::GetShapesOnSphere
//=======================================================================
//function : getShapesOnQuadrangleIDs
/*!
- * \brief Find IDs of subshapes complying with given status about quadrangle
+ * \brief Find IDs of sub-shapes complying with given status about quadrangle
* \param theShape - the shape to explore
- * \param theShapeType - type of subshape of theShape
+ * \param theShapeType - type of sub-shape of theShape
* \param theTopLeftPoint - top left quadrangle corner
* \param theTopRigthPoint - top right quadrangle corner
* \param theBottomLeftPoint - bottom left quadrangle corner
* \param theBottomRigthPoint - bottom right quadrangle corner
* \param theState - required state
- * \retval Handle(TColStd_HSequenceOfInteger) - IDs of found subshapes
+ * \retval Handle(TColStd_HSequenceOfInteger) - IDs of found sub-shapes
*/
//=======================================================================
Handle(TColStd_HSequenceOfInteger)
@@ -3444,15 +3444,15 @@ Handle(TColStd_HSequenceOfInteger)
//=======================================================================
//function : GetShapesOnQuadrangle
/*!
- * \brief Find subshapes complying with given status about quadrangle
+ * \brief Find sub-shapes complying with given status about quadrangle
* \param theShape - the shape to explore
- * \param theShapeType - type of subshape of theShape
+ * \param theShapeType - type of sub-shape of theShape
* \param theTopLeftPoint - top left quadrangle corner
* \param theTopRigthPoint - top right quadrangle corner
* \param theBottomLeftPoint - bottom left quadrangle corner
* \param theBottomRigthPoint - bottom right quadrangle corner
* \param theState - required state
- * \retval Handle(TColStd_HSequenceOfInteger) - IDs of found subshapes
+ * \retval Handle(TColStd_HSequenceOfInteger) - IDs of found sub-shapes
*/
//=======================================================================
Handle(TColStd_HSequenceOfTransient)
@@ -3505,15 +3505,15 @@ Handle(TColStd_HSequenceOfTransient)
//=======================================================================
//function : GetShapesOnQuadrangleIDs
/*!
- * \brief Find IDs of subshapes complying with given status about quadrangle
+ * \brief Find IDs of sub-shapes complying with given status about quadrangle
* \param theShape - the shape to explore
- * \param theShapeType - type of subshape of theShape
+ * \param theShapeType - type of sub-shape of theShape
* \param theTopLeftPoint - top left quadrangle corner
* \param theTopRigthPoint - top right quadrangle corner
* \param theBottomLeftPoint - bottom left quadrangle corner
* \param theBottomRigthPoint - bottom right quadrangle corner
* \param theState - required state
- * \retval Handle(TColStd_HSequenceOfInteger) - IDs of found subshapes
+ * \retval Handle(TColStd_HSequenceOfInteger) - IDs of found sub-shapes
*/
//=======================================================================
Handle(TColStd_HSequenceOfInteger)
@@ -3764,7 +3764,7 @@ namespace {
//================================================================================
/*!
- * \brief Return type of shape for explode. In case of compound it will be a type of sub shape.
+ * \brief Return type of shape for explode. In case of compound it will be a type of sub-shape.
*/
//================================================================================
TopAbs_ShapeEnum GEOMImpl_IShapesOperations::GetTypeOfSimplePart (const TopoDS_Shape& theShape)
@@ -3921,7 +3921,7 @@ Handle(GEOM_Object) GEOMImpl_IShapesOperations::GetInPlace (Handle(GEOM_Object)
aModifiedArray->SetValue(imod, aWhereIndices.FindIndex(anIterModif.Value()));
}
else {
- SetErrorCode("Error: wrong sub shape returned");
+ SetErrorCode("Error: wrong sub-shape returned");
return NULL;
}
}
@@ -3937,7 +3937,7 @@ Handle(GEOM_Object) GEOMImpl_IShapesOperations::GetInPlace (Handle(GEOM_Object)
//Set a GROUP type
aResult->SetType(GEOM_GROUP);
- //Set a sub shape type
+ //Set a sub-shape type
TopoDS_Shape aFirstFound = aLSA.First();
TopAbs_ShapeEnum aShapeType = aFirstFound.ShapeType();
@@ -4165,7 +4165,7 @@ Handle(GEOM_Object) GEOMImpl_IShapesOperations::GetInPlaceOld (Handle(GEOM_Objec
//Set a GROUP type
aResult->SetType(GEOM_GROUP);
- //Set a sub shape type
+ //Set a sub-shape type
TopoDS_Shape aFirstFound = aWhereIndices.FindKey(aModifiedArray->Value(1));
TopAbs_ShapeEnum aShapeType = aFirstFound.ShapeType();
@@ -4234,7 +4234,7 @@ Handle(GEOM_Object) GEOMImpl_IShapesOperations::GetInPlaceByHistory
//Set a GROUP type
aResult->SetType(GEOM_GROUP);
- //Set a sub shape type
+ //Set a sub-shape type
TopoDS_Shape aFirstFound = aWhereIndices.FindKey(aModifiedArray->Value(1));
TopAbs_ShapeEnum aShapeType = aFirstFound.ShapeType();
diff --git a/src/GEOMImpl/GEOMImpl_IShapesOperations.hxx b/src/GEOMImpl/GEOMImpl_IShapesOperations.hxx
index c30ae1868..e483b524f 100644
--- a/src/GEOMImpl/GEOMImpl_IShapesOperations.hxx
+++ b/src/GEOMImpl/GEOMImpl_IShapesOperations.hxx
@@ -236,15 +236,15 @@ class GEOMImpl_IShapesOperations : public GEOM_IOperations
const GEOMAlgo_State theState);
/*!
- * \brief Find subshapes complying with given status about quadrangle
+ * \brief Find sub-shapes complying with given status about quadrangle
* \param theShape - the shape to explore
- * \param theShapeType - type of subshape of theShape
+ * \param theShapeType - type of sub-shape of theShape
* \param theTopLeftPoint - top left quadrangle corner
* \param theTopRigthPoint - top right quadrangle corner
* \param theBottomLeftPoint - bottom left quadrangle corner
* \param theBottomRigthPoint - bottom right quadrangle corner
* \param theState - required state
- * \retval Handle(TColStd_HSequenceOfInteger) - IDs of found subshapes
+ * \retval Handle(TColStd_HSequenceOfInteger) - IDs of found sub-shapes
*/
Standard_EXPORT Handle(TColStd_HSequenceOfTransient)
GetShapesOnQuadrangle (const Handle(GEOM_Object)& theShape,
@@ -256,15 +256,15 @@ class GEOMImpl_IShapesOperations : public GEOM_IOperations
const GEOMAlgo_State theState);
/*!
- * \brief Find IDs of subshapes complying with given status about quadrangle
+ * \brief Find IDs of sub-shapes complying with given status about quadrangle
* \param theShape - the shape to explore
- * \param theShapeType - type of subshape of theShape
+ * \param theShapeType - type of sub-shape of theShape
* \param theTopLeftPoint - top left quadrangle corner
* \param theTopRigthPoint - top right quadrangle corner
* \param theBottomLeftPoint - bottom left quadrangle corner
* \param theBottomRigthPoint - bottom right quadrangle corner
* \param theState - required state
- * \retval Handle(TColStd_HSequenceOfInteger) - IDs of found subshapes
+ * \retval Handle(TColStd_HSequenceOfInteger) - IDs of found sub-shapes
*/
Standard_EXPORT Handle(TColStd_HSequenceOfInteger)
GetShapesOnQuadrangleIDs (const Handle(GEOM_Object)& theShape,
@@ -306,12 +306,12 @@ class GEOMImpl_IShapesOperations : public GEOM_IOperations
const Handle(GEOM_Object)& theShapeWhat);
/*!
- * \brief Find IDs of subshapes complying with given status about surface
- * \param theBox - the box to check state of subshapes against
+ * \brief Find IDs of sub-shapes complying with given status about surface
+ * \param theBox - the box to check state of sub-shapes against
* \param theShape - the shape to explore
- * \param theShapeType - type of subshape of theShape
+ * \param theShapeType - type of sub-shape of theShape
* \param theState - required state
- * \retval Handle(TColStd_HSequenceOfInteger) - IDs of found subshapes
+ * \retval Handle(TColStd_HSequenceOfInteger) - IDs of found sub-shapes
*/
Standard_EXPORT Handle(TColStd_HSequenceOfInteger)
GetShapesOnBoxIDs(const Handle(GEOM_Object)& theBox,
@@ -320,10 +320,10 @@ class GEOMImpl_IShapesOperations : public GEOM_IOperations
GEOMAlgo_State theState);
/*!
- * \brief Find subshapes complying with given status about surface
- * \param theBox - the box to check state of subshapes against
+ * \brief Find sub-shapes complying with given status about surface
+ * \param theBox - the box to check state of sub-shapes against
* \param theShape - the shape to explore
- * \param theShapeType - type of subshape of theShape
+ * \param theShapeType - type of sub-shape of theShape
* \param theState - required state
* \retval Handle(TColStd_HSequenceOfTransient) - found shape objects
*/
@@ -334,12 +334,12 @@ class GEOMImpl_IShapesOperations : public GEOM_IOperations
GEOMAlgo_State theState);
/*!
- * \brief Find IDs of subshapes complying with given status about surface
- * \param theCheckShape - the shape to check state of subshapes against
+ * \brief Find IDs of sub-shapes complying with given status about surface
+ * \param theCheckShape - the shape to check state of sub-shapes against
* \param theShape - the shape to explore
- * \param theShapeType - type of subshape of theShape
+ * \param theShapeType - type of sub-shape of theShape
* \param theState - required state
- * \retval Handle(TColStd_HSequenceOfInteger) - IDs of found subshapes
+ * \retval Handle(TColStd_HSequenceOfInteger) - IDs of found sub-shapes
*/
Standard_EXPORT Handle(TColStd_HSequenceOfInteger)
GetShapesOnShapeIDs(const Handle(GEOM_Object)& theCheckShape,
@@ -348,10 +348,10 @@ class GEOMImpl_IShapesOperations : public GEOM_IOperations
GEOMAlgo_State theState);
/*!
- * \brief Find subshapes complying with given status about surface
- * \param theCheckShape - the shape to check state of subshapes against
+ * \brief Find sub-shapes complying with given status about surface
+ * \param theCheckShape - the shape to check state of sub-shapes against
* \param theShape - the shape to explore
- * \param theShapeType - type of subshape of theShape
+ * \param theShapeType - type of sub-shape of theShape
* \param theState - required state
* \retval Handle(TColStd_HSequenceOfTransient) - found shape objects
*/
@@ -444,12 +444,12 @@ class GEOMImpl_IShapesOperations : public GEOM_IOperations
const Standard_Real theRadius);
/*!
- * \brief Find IDs of subshapes complying with given status about surface
- * \param theSurface - the surface to check state of subshapes against
+ * \brief Find IDs of sub-shapes complying with given status about surface
+ * \param theSurface - the surface to check state of sub-shapes against
* \param theShape - the shape to explore
- * \param theShapeType - type of subshape of theShape
+ * \param theShapeType - type of sub-shape of theShape
* \param theState - required state
- * \retval Handle(TColStd_HSequenceOfInteger) - IDs of found subshapes
+ * \retval Handle(TColStd_HSequenceOfInteger) - IDs of found sub-shapes
*/
Handle(TColStd_HSequenceOfInteger)
getShapesOnSurfaceIDs(const Handle(Geom_Surface)& theSurface,
@@ -458,10 +458,10 @@ class GEOMImpl_IShapesOperations : public GEOM_IOperations
GEOMAlgo_State theState);
/*!
- * \brief Find subshapes complying with given status about surface
- * \param theSurface - the surface to check state of subshapes against
+ * \brief Find sub-shapes complying with given status about surface
+ * \param theSurface - the surface to check state of sub-shapes against
* \param theShape - the shape to explore
- * \param theShapeType - type of subshape of theShape
+ * \param theShapeType - type of sub-shape of theShape
* \param theState - required state
* \param theShapeEntries - outgoing entries like "entry1, entry2, ..."
* \retval Handle(TColStd_HSequenceOfTransient) - found shape objects
@@ -474,15 +474,15 @@ class GEOMImpl_IShapesOperations : public GEOM_IOperations
TCollection_AsciiString & theShapeEntries);
/*!
- * \brief Find IDs of subshapes complying with given status about quadrangle
+ * \brief Find IDs of sub-shapes complying with given status about quadrangle
* \param theShape - the shape to explore
- * \param theShapeType - type of subshape of theShape
+ * \param theShapeType - type of sub-shape of theShape
* \param theTopLeftPoint - top left quadrangle corner
* \param theTopRigthPoint - top right quadrangle corner
* \param theBottomLeftPoint - bottom left quadrangle corner
* \param theBottomRigthPoint - bottom right quadrangle corner
* \param theState - required state
- * \retval Handle(TColStd_HSequenceOfInteger) - IDs of found subshapes
+ * \retval Handle(TColStd_HSequenceOfInteger) - IDs of found sub-shapes
*/
Handle(TColStd_HSequenceOfInteger)
getShapesOnQuadrangleIDs (const Handle(GEOM_Object)& theShape,
@@ -494,12 +494,12 @@ class GEOMImpl_IShapesOperations : public GEOM_IOperations
const GEOMAlgo_State theState);
/*!
- * \brief Find IDs of subshapes complying with given status about surface
- * \param theBox - the box to check state of subshapes against
+ * \brief Find IDs of sub-shapes complying with given status about surface
+ * \param theBox - the box to check state of sub-shapes against
* \param theShape - the shape to explore
- * \param theShapeType - type of subshape of theShape
+ * \param theShapeType - type of sub-shape of theShape
* \param theState - required state
- * \retval Handle(TColStd_HSequenceOfInteger) - IDs of found subshapes
+ * \retval Handle(TColStd_HSequenceOfInteger) - IDs of found sub-shapes
*/
Handle(TColStd_HSequenceOfInteger) getShapesOnBoxIDs(const Handle(GEOM_Object)& theBox,
const Handle(GEOM_Object)& theShape,
@@ -507,12 +507,12 @@ class GEOMImpl_IShapesOperations : public GEOM_IOperations
GEOMAlgo_State theState);
/*!
- * \brief Find IDs of subshapes complying with given status about surface
- * \param theCheckShape - the shape to check state of subshapes against
+ * \brief Find IDs of sub-shapes complying with given status about surface
+ * \param theCheckShape - the shape to check state of sub-shapes against
* \param theShape - the shape to explore
- * \param theShapeType - type of subshape of theShape
+ * \param theShapeType - type of sub-shape of theShape
* \param theState - required state
- * \retval Handle(TColStd_HSequenceOfInteger) - IDs of found subshapes
+ * \retval Handle(TColStd_HSequenceOfInteger) - IDs of found sub-shapes
*/
Handle(TColStd_HSequenceOfInteger) getShapesOnShapeIDs
(const Handle(GEOM_Object)& theCheckShape,
diff --git a/src/GEOMImpl/GEOMImpl_PipeDriver.cxx b/src/GEOMImpl/GEOMImpl_PipeDriver.cxx
index 93263f51e..7bb6a7503 100644
--- a/src/GEOMImpl/GEOMImpl_PipeDriver.cxx
+++ b/src/GEOMImpl/GEOMImpl_PipeDriver.cxx
@@ -502,7 +502,7 @@ static void FindFirstPairFaces(const TopoDS_Shape& S1, const TopoDS_Shape& S2,
{
//cout<<"FindFirstPairFaces"<face (and subshapes)
+ // constuct map face->face (and sub-shapes)
TopTools_IndexedDataMapOfShapeShape FF;
//TopoDS_Shape FS1 = SecFs.Value(i), FS2 = SecFs.Value(i+1);
TopoDS_Shape FS1, FS2;
@@ -1839,7 +1839,7 @@ static TopoDS_Shape CreatePipeShellsWithoutPath(GEOMImpl_IPipe* aCI)
if (aCI) delete aCI;
Standard_ConstructionError::Raise("Can not create correct pipe");
}
- MESSAGE (" correspondences for subshapes of first pair of faces is found");
+ MESSAGE (" correspondences for sub-shapes of first pair of faces is found");
FindNextPairOfFaces(FS1, aMapEdgeFaces1, aMapEdgeFaces2, FF, aCI);
MESSAGE (" other correspondences is found, make pipe for all pairs of faces");
diff --git a/src/GEOMImpl/GEOMImpl_PipeTShapeDriver.cxx b/src/GEOMImpl/GEOMImpl_PipeTShapeDriver.cxx
index 670473b4c..7e20b90c4 100644
--- a/src/GEOMImpl/GEOMImpl_PipeTShapeDriver.cxx
+++ b/src/GEOMImpl/GEOMImpl_PipeTShapeDriver.cxx
@@ -89,12 +89,12 @@ GEOMImpl_PipeTShapeDriver::GEOMImpl_PipeTShapeDriver()
//=======================================================================
//function : getShapesOnBoxIDs
/*!
- * \brief Find IDs of subshapes complying with given status about surface
- * \param theBox - the box to check state of subshapes against
+ * \brief Find IDs of sub-shapes complying with given status about surface
+ * \param theBox - the box to check state of sub-shapes against
* \param theShape - the shape to explore
- * \param theShapeType - type of subshape of theShape
+ * \param theShapeType - type of sub-shape of theShape
* \param theState - required state
- * \retval Handle(TColStd_HSequenceOfInteger) - IDs of found subshapes
+ * \retval Handle(TColStd_HSequenceOfInteger) - IDs of found sub-shapes
*/
//=======================================================================
Handle(TColStd_HSequenceOfInteger)
@@ -162,12 +162,12 @@ GEOMImpl_PipeTShapeDriver::GetShapesOnBoxIDs(const TopoDS_Shape& aBox,
//=======================================================================
//function : GetShapesOnSurfaceIDs
/*!
- * \brief Find IDs of subshapes complying with given status about surface
- * \param theSurface - the surface to check state of subshapes against
+ * \brief Find IDs of sub-shapes complying with given status about surface
+ * \param theSurface - the surface to check state of sub-shapes against
* \param theShape - the shape to explore
- * \param theShapeType - type of subshape of theShape
+ * \param theShapeType - type of sub-shape of theShape
* \param theState - required state
- * \retval Handle(TColStd_HSequenceOfInteger) - IDs of found subshapes
+ * \retval Handle(TColStd_HSequenceOfInteger) - IDs of found sub-shapes
*/
//=======================================================================
Handle(TColStd_HSequenceOfInteger)
diff --git a/src/GEOMImpl/GEOMImpl_PipeTShapeDriver.hxx b/src/GEOMImpl/GEOMImpl_PipeTShapeDriver.hxx
index 5479fead6..deb39d2c7 100644
--- a/src/GEOMImpl/GEOMImpl_PipeTShapeDriver.hxx
+++ b/src/GEOMImpl/GEOMImpl_PipeTShapeDriver.hxx
@@ -152,12 +152,12 @@ private:
//=======================================================================
//function : GetShapesOnSurfaceIDs
/*!
- * \brief Find IDs of subshapes complying with given status about surface
- * \param theSurface - the surface to check state of subshapes against
+ * \brief Find IDs of sub-shapes complying with given status about surface
+ * \param theSurface - the surface to check state of sub-shapes against
* \param theShape - the shape to explore
- * \param theShapeType - type of subshape of theShape
+ * \param theShapeType - type of sub-shape of theShape
* \param theState - required state
- * \retval Handle(TColStd_HSequenceOfInteger) - IDs of found subshapes
+ * \retval Handle(TColStd_HSequenceOfInteger) - IDs of found sub-shapes
*/
Handle(TColStd_HSequenceOfInteger)
GetShapesOnSurfaceIDs(const Handle(Geom_Surface)& theSurface,
@@ -167,12 +167,12 @@ private:
//=======================================================================
//function : getShapesOnBoxIDs
/*!
- * \brief Find IDs of subshapes complying with given status about surface
- * \param theBox - the box to check state of subshapes against
+ * \brief Find IDs of sub-shapes complying with given status about surface
+ * \param theBox - the box to check state of sub-shapes against
* \param theShape - the shape to explore
- * \param theShapeType - type of subshape of theShape
+ * \param theShapeType - type of sub-shape of theShape
* \param theState - required state
- * \retval Handle(TColStd_HSequenceOfInteger) - IDs of found subshapes
+ * \retval Handle(TColStd_HSequenceOfInteger) - IDs of found sub-shapes
*/
//=======================================================================
Handle(TColStd_HSequenceOfInteger)
diff --git a/src/GEOMImpl/GUID.txt b/src/GEOMImpl/GUID.txt
index 36c4af1cc..be669b2b6 100755
--- a/src/GEOMImpl/GUID.txt
+++ b/src/GEOMImpl/GUID.txt
@@ -39,7 +39,7 @@ FF1BBB53-5D14-4df2-980B-3A668264EA16 // Copy
FF1BBB54-5D14-4df2-980B-3A668264EA16 // Shape (Wire, Face, Shell, Solid, Compound)
-FF1BBB55-5D14-4df2-980B-3A668264EA16 // Subshape
+FF1BBB55-5D14-4df2-980B-3A668264EA16 // Sub-shape
FF1BBB56-5D14-4df2-980B-3A668264EA16 // Rotate
@@ -65,7 +65,7 @@ FF1BBB66-5D14-4df2-980B-3A668264EA16 // Group
FF1BBB67-5D14-4df2-980B-3A668264EA16 // Blocks
-FF1BBB68-5D14-4df2-980B-3A668264EA16 // Sub shape GUID
+FF1BBB68-5D14-4df2-980B-3A668264EA16 // Sub-shape GUID
FF1BBB69-5D14-4df2-980B-3A668264EA16 // Modify the Location
diff --git a/src/GEOM_I/GEOM_Gen_i.hh b/src/GEOM_I/GEOM_Gen_i.hh
index 79cf0bcc0..c82d7e9b8 100644
--- a/src/GEOM_I/GEOM_Gen_i.hh
+++ b/src/GEOM_I/GEOM_Gen_i.hh
@@ -241,7 +241,7 @@ class GEOM_I_EXPORT GEOM_Gen_i: virtual public POA_GEOM::GEOM_Gen, virtual publi
virtual GEOM::GEOM_IAdvancedOperations_ptr GetIAdvancedOperations (CORBA::Long theStudyID)
throw (SALOME::SALOME_Exception);
- //Adds a new sub shape
+ //Adds a new sub-shape
virtual GEOM::GEOM_Object_ptr AddSubShape (GEOM::GEOM_Object_ptr theMainShape,
const GEOM::ListOfLong& theIndices);
diff --git a/src/GEOM_I/GEOM_ITransformOperations_i.cc b/src/GEOM_I/GEOM_ITransformOperations_i.cc
index bdb27163d..79659a878 100644
--- a/src/GEOM_I/GEOM_ITransformOperations_i.cc
+++ b/src/GEOM_I/GEOM_ITransformOperations_i.cc
@@ -78,7 +78,7 @@ GEOM::GEOM_Object_ptr GEOM_ITransformOperations_i::TranslateTwoPoints
if (CORBA::is_nil(theObject)) return aGEOMObject._retn();
- //check if the object is a subshape
+ //check if the object is a sub-shape
if (!theObject->IsMainShape()) {
GetOperations()->SetErrorCode(SUBSHAPE_ERROR);
return aGEOMObject._retn();
@@ -155,7 +155,7 @@ GEOM::GEOM_Object_ptr GEOM_ITransformOperations_i::TranslateDXDYDZ
if (CORBA::is_nil(theObject)) return aGEOMObject._retn();
- //check if the object is a subshape
+ //check if the object is a sub-shape
if (!theObject->IsMainShape()) {
GetOperations()->SetErrorCode(SUBSHAPE_ERROR);
return aGEOMObject._retn();
@@ -215,7 +215,7 @@ GEOM::GEOM_Object_ptr GEOM_ITransformOperations_i::TranslateVector
if (CORBA::is_nil(theObject)) return aGEOMObject._retn();
- //check if the object is a subshape
+ //check if the object is a sub-shape
if (!theObject->IsMainShape()) {
GetOperations()->SetErrorCode(SUBSHAPE_ERROR);
return aGEOMObject._retn();
@@ -283,7 +283,7 @@ GEOM::GEOM_Object_ptr GEOM_ITransformOperations_i::TranslateVectorDistance
if (CORBA::is_nil(theObject)) return aGEOMObject._retn();
- //check if the object is a subshape
+ //check if the object is a sub-shape
if (!theCopy && !theObject->IsMainShape()) {
GetOperations()->SetErrorCode(SUBSHAPE_ERROR);
return aGEOMObject._retn();
@@ -329,7 +329,7 @@ GEOM::GEOM_Object_ptr GEOM_ITransformOperations_i::Rotate (GEOM::GEOM_Object_ptr
if (CORBA::is_nil(theObject)) return aGEOMObject._retn();
- //check if the object is a subshape
+ //check if the object is a sub-shape
if (!theObject->IsMainShape()) {
GetOperations()->SetErrorCode(SUBSHAPE_ERROR);
return aGEOMObject._retn();
@@ -397,7 +397,7 @@ GEOM::GEOM_Object_ptr GEOM_ITransformOperations_i::MirrorPlane
if (CORBA::is_nil(theObject)) return aGEOMObject._retn();
- //check if the object is a subshape
+ //check if the object is a sub-shape
if (!theObject->IsMainShape()) {
GetOperations()->SetErrorCode(SUBSHAPE_ERROR);
return aGEOMObject._retn();
@@ -463,7 +463,7 @@ GEOM::GEOM_Object_ptr GEOM_ITransformOperations_i::MirrorAxis
if (CORBA::is_nil(theObject)) return aGEOMObject._retn();
- //check if the object is a subshape
+ //check if the object is a sub-shape
if (!theObject->IsMainShape()) {
GetOperations()->SetErrorCode(SUBSHAPE_ERROR);
return aGEOMObject._retn();
@@ -529,7 +529,7 @@ GEOM::GEOM_Object_ptr GEOM_ITransformOperations_i::MirrorPoint
if (CORBA::is_nil(theObject)) return aGEOMObject._retn();
- //check if the object is a subshape
+ //check if the object is a sub-shape
if (!theObject->IsMainShape()) {
GetOperations()->SetErrorCode(SUBSHAPE_ERROR);
return aGEOMObject._retn();
@@ -595,7 +595,7 @@ GEOM::GEOM_Object_ptr GEOM_ITransformOperations_i::OffsetShape
if (CORBA::is_nil(theObject)) return aGEOMObject._retn();
- //check if the object is a subshape
+ //check if the object is a sub-shape
if (!theObject->IsMainShape()) {
GetOperations()->SetErrorCode(SUBSHAPE_ERROR);
return aGEOMObject._retn();
@@ -681,7 +681,7 @@ GEOM::GEOM_Object_ptr GEOM_ITransformOperations_i::ScaleShape
if (theObject->_is_nil()) return aGEOMObject._retn();
- //check if the object is a subshape
+ //check if the object is a sub-shape
if (!theObject->IsMainShape()) {
GetOperations()->SetErrorCode(SUBSHAPE_ERROR);
return aGEOMObject._retn();
@@ -758,7 +758,7 @@ GEOM::GEOM_Object_ptr GEOM_ITransformOperations_i::ScaleShapeAlongAxes
if (theObject->_is_nil()) return aGEOMObject._retn();
- //check if the object is a subshape
+ //check if the object is a sub-shape
if (!theObject->IsMainShape()) {
GetOperations()->SetErrorCode(SUBSHAPE_ERROR);
return aGEOMObject._retn();
@@ -837,7 +837,7 @@ GEOM::GEOM_Object_ptr GEOM_ITransformOperations_i::PositionShape
if (CORBA::is_nil(theObject) || CORBA::is_nil(theEndLCS))
return aGEOMObject._retn();
- //check if the object is a subshape
+ //check if the object is a sub-shape
if (!theObject->IsMainShape()) {
GetOperations()->SetErrorCode(SUBSHAPE_ERROR);
return aGEOMObject._retn();
@@ -1086,7 +1086,7 @@ GEOM::GEOM_Object_ptr GEOM_ITransformOperations_i::RotateThreePoints
if (CORBA::is_nil(theObject))
return aGEOMObject._retn();
- //check if the object is a subshape
+ //check if the object is a sub-shape
if (!theObject->IsMainShape()) {
GetOperations()->SetErrorCode(SUBSHAPE_ERROR);
return aGEOMObject._retn();
diff --git a/src/GEOM_I/GEOM_Object_i.cc b/src/GEOM_I/GEOM_Object_i.cc
index b1a37b1ff..e18ad60d5 100644
--- a/src/GEOM_I/GEOM_Object_i.cc
+++ b/src/GEOM_I/GEOM_Object_i.cc
@@ -453,7 +453,7 @@ GEOM::ListOfLong* GEOM_Object_i::GetSubShapeIndices()
GEOM::ListOfLong_var anIndices = new GEOM::ListOfLong;
if(!_impl->IsMainShape()) {
- Handle(GEOM_Function) aFunction = _impl->GetFunction(1); //Get SubShape function (always the first (and last) one)
+ Handle(GEOM_Function) aFunction = _impl->GetFunction(1); //Get Sub-shape function (always the first (and last) one)
if(aFunction.IsNull()) return anIndices._retn();
GEOM_ISubShape ISS(aFunction);
Handle(TColStd_HArray1OfInteger) anArray = ISS.GetIndices();
@@ -478,7 +478,7 @@ GEOM::GEOM_Object_ptr GEOM_Object_i::GetMainShape()
{
GEOM::GEOM_Object_var obj;
if(!_impl->IsMainShape()) {
- Handle(GEOM_Function) aFunction = _impl->GetFunction(1); //Get SubShape function (always the first (and last) one)
+ Handle(GEOM_Function) aFunction = _impl->GetFunction(1); //Get Sub-shape function (always the first (and last) one)
if(aFunction.IsNull()) return obj._retn();
GEOM_ISubShape ISS(aFunction);
diff --git a/src/GEOM_PY/structelem/parts.py b/src/GEOM_PY/structelem/parts.py
index a533125fe..406cb1a27 100644
--- a/src/GEOM_PY/structelem/parts.py
+++ b/src/GEOM_PY/structelem/parts.py
@@ -64,8 +64,8 @@ class InvalidParameterError(Exception):
class SubShapeID:
"""
- This class enables the use of subshapes in sets or as dictionary keys.
- It implements __eq__ and __hash__ methods so that subshapes with the same
+ This class enables the use of sub-shapes in sets or as dictionary keys.
+ It implements __eq__ and __hash__ methods so that sub-shapes with the same
CORBA object `mainShape` and the same `id` are considered equal.
"""
@@ -75,7 +75,7 @@ class SubShapeID:
def getObj(self, geom):
"""
- Return the subshape (GEOM object). `geom` is a pseudo-geompy object
+ Return the sub-shape (GEOM object). `geom` is a pseudo-geompy object
used to find the geometrical object.
"""
return geom.GetSubShape(self._mainShape, [self._id])
@@ -217,7 +217,7 @@ class StructuralElementPart:
def _getSubShapes(self, minDim = MIN_LENGTH_FOR_EXTRUSION):
"""
- Find and return the base subshapes in the structural element part.
+ Find and return the base sub-shapes in the structural element part.
"""
subShapes = []
for subShapeID in self.baseShapesSet:
@@ -296,7 +296,7 @@ class Beam(StructuralElementPart):
"""
Build the structural element part.
"""
- # Get all the subshapes in the group (normally only edges and wires)
+ # Get all the sub-shapes in the group (normally only edges and wires)
paths = self._getSubShapes()
listPipes = []
withContact = False
diff --git a/src/GEOM_SWIG/GEOM_Partition1.py b/src/GEOM_SWIG/GEOM_Partition1.py
index 125798d75..2a65bcd1d 100755
--- a/src/GEOM_SWIG/GEOM_Partition1.py
+++ b/src/GEOM_SWIG/GEOM_Partition1.py
@@ -85,7 +85,7 @@ geompy.addToStudy(alveole, "alveole before explode")
subshapes = geompy.SubShapeAll(alveole, geompy.ShapeType["SHAPE"])
-## there are 9 subshapes
+## there are 9 sub-shapes
comp1 = geompy.MakeCompound([subshapes[0], subshapes[1]]);
comp2 = geompy.MakeCompound([subshapes[2], subshapes[3]]);
diff --git a/src/GEOM_SWIG/geompyDC.py b/src/GEOM_SWIG/geompyDC.py
index 435d8fd59..cc02d2bc6 100644
--- a/src/GEOM_SWIG/geompyDC.py
+++ b/src/GEOM_SWIG/geompyDC.py
@@ -52,7 +52,7 @@
## @defgroup l4_decompose Decompose objects
## @defgroup l4_decompose_d Decompose objects deprecated methods
## @defgroup l4_access Access to sub-shapes by their unique IDs inside the main shape
-## @defgroup l4_obtain Access to subshapes by a criteria
+## @defgroup l4_obtain Access to sub-shapes by a criteria
## @defgroup l4_advanced Advanced objects creation functions
## @}
@@ -66,7 +66,7 @@
## @defgroup l3_local Local Operations (Fillet and Chamfer)
## @defgroup l3_blocks_op Blocks Operations
## @defgroup l3_healing Repairing Operations
-## @defgroup l3_restore_ss Restore presentation parameters and a tree of subshapes
+## @defgroup l3_restore_ss Restore presentation parameters and a tree of sub-shapes
## @}
## @defgroup l2_measure Using measurement tools
@@ -410,11 +410,11 @@ class geompyDC(GEOM._objref_GEOM_Gen):
# \param theObject published GEOM object, arguments of which will be published
# \param theArgs list of GEOM_Object, operation arguments to be published.
# If this list is empty, all operation arguments will be published
- # \param theFindMethod method to search subshapes, corresponding to arguments and
- # their subshapes. Value from enumeration GEOM::find_shape_method.
+ # \param theFindMethod method to search sub-shapes, corresponding to arguments and
+ # their sub-shapes. Value from enumeration GEOM::find_shape_method.
# \param theInheritFirstArg set properties of the first argument for theObject.
- # Do not publish subshapes in place of arguments, but only
- # in place of subshapes of the first argument,
+ # Do not publish sub-shapes in place of arguments, but only
+ # in place of sub-shapes of the first argument,
# because the whole shape corresponds to the first argument.
# Mainly to be used after transformations, but it also can be
# usefull after partition with one object shape, and some other
@@ -422,7 +422,7 @@ class geompyDC(GEOM._objref_GEOM_Gen):
# If theObject has only one argument shape, this flag is automatically
# considered as True, not regarding really passed value.
# \param theAddPrefix add prefix "from_" to names of restored sub-shapes,
- # and prefix "from_subshapes_of_" to names of partially restored subshapes.
+ # and prefix "from_subshapes_of_" to names of partially restored sub-shapes.
# \return list of published sub-shapes
#
# @ref tui_restore_prs_params "Example"
@@ -437,11 +437,11 @@ class geompyDC(GEOM._objref_GEOM_Gen):
# \param theObject published GEOM object, arguments of which will be published
# \param theArgs list of GEOM_Object, operation arguments to be published.
# If this list is empty, all operation arguments will be published
- # \param theFindMethod method to search subshapes, corresponding to arguments and
- # their subshapes. Value from enumeration GEOM::find_shape_method.
+ # \param theFindMethod method to search sub-shapes, corresponding to arguments and
+ # their sub-shapes. Value from enumeration GEOM::find_shape_method.
# \param theInheritFirstArg set properties of the first argument for theObject.
- # Do not publish subshapes in place of arguments, but only
- # in place of subshapes of the first argument,
+ # Do not publish sub-shapes in place of arguments, but only
+ # in place of sub-shapes of the first argument,
# because the whole shape corresponds to the first argument.
# Mainly to be used after transformations, but it also can be
# usefull after partition with one object shape, and some other
@@ -449,7 +449,7 @@ class geompyDC(GEOM._objref_GEOM_Gen):
# If theObject has only one argument shape, this flag is automatically
# considered as True, not regarding really passed value.
# \param theAddPrefix add prefix "from_" to names of restored sub-shapes,
- # and prefix "from_subshapes_of_" to names of partially restored subshapes.
+ # and prefix "from_subshapes_of_" to names of partially restored sub-shapes.
# \return list of published sub-shapes
#
# @ref tui_restore_prs_params "Example"
@@ -1569,7 +1569,7 @@ class geompyDC(GEOM._objref_GEOM_Gen):
# shell or face. If number of faces in neighbour sections
# aren't coincided result solid between such sections will
# be created using external boundaries of this shells.
- # @param theSeqSubBases - list of corresponding subshapes of section shapes.
+ # @param theSeqSubBases - list of corresponding sub-shapes of section shapes.
# This list is used for searching correspondences between
# faces in the sections. Size of this list must be equal
# to size of list of base shapes.
@@ -1823,10 +1823,10 @@ class geompyDC(GEOM._objref_GEOM_Gen):
RaiseIfFailed("NumberOfEdges", self.ShapesOp)
return nb_edges
- ## Gives quantity of subshapes of type theShapeType in the given shape.
- # @param theShape Shape to count subshapes of.
- # @param theShapeType Type of subshapes to count.
- # @return Quantity of subshapes of given type.
+ ## Gives quantity of sub-shapes of type theShapeType in the given shape.
+ # @param theShape Shape to count sub-shapes of.
+ # @param theShapeType Type of sub-shapes to count.
+ # @return Quantity of sub-shapes of given type.
#
# @ref swig_NumberOf "Example"
def NumberOfSubShapes(self, theShape, theShapeType):
@@ -1921,7 +1921,7 @@ class geompyDC(GEOM._objref_GEOM_Gen):
# @param theShapeType Type of sub-shapes to be retrieved.
# @param theAx1 Vector (or line, or linear edge), specifying normal
# direction and location of the plane to find shapes on.
- # @param theState The state of the subshapes to find. It can be one of
+ # @param theState The state of the sub-shapes to find. It can be one of
# ST_ON, ST_OUT, ST_ONOUT, ST_IN, ST_ONIN.
# @return List of all found sub-shapes.
#
@@ -1949,7 +1949,7 @@ class geompyDC(GEOM._objref_GEOM_Gen):
# @param theAx1 Vector (or line, or linear edge), specifying normal
# direction of the plane to find shapes on.
# @param thePnt Point specifying location of the plane to find shapes on.
- # @param theState The state of the subshapes to find. It can be one of
+ # @param theState The state of the sub-shapes to find. It can be one of
# ST_ON, ST_OUT, ST_ONOUT, ST_IN, ST_ONIN.
# @return List of all found sub-shapes.
#
@@ -1978,7 +1978,7 @@ class geompyDC(GEOM._objref_GEOM_Gen):
# @param theAxis Vector (or line, or linear edge), specifying
# axis of the cylinder to find shapes on.
# @param theRadius Radius of the cylinder to find shapes on.
- # @param theState The state of the subshapes to find. It can be one of
+ # @param theState The state of the sub-shapes to find. It can be one of
# ST_ON, ST_OUT, ST_ONOUT, ST_IN, ST_ONIN.
# @return List of all found sub-shapes.
#
@@ -2006,7 +2006,7 @@ class geompyDC(GEOM._objref_GEOM_Gen):
# axis of the cylinder to find shapes on.
# @param thePnt Point specifying location of the bottom of the cylinder.
# @param theRadius Radius of the cylinder to find shapes on.
- # @param theState The state of the subshapes to find. It can be one of
+ # @param theState The state of the sub-shapes to find. It can be one of
# ST_ON, ST_OUT, ST_ONOUT, ST_IN, ST_ONIN.
# @return List of all found sub-shapes.
#
@@ -2032,7 +2032,7 @@ class geompyDC(GEOM._objref_GEOM_Gen):
# @param theShapeType Type of sub-shapes to be retrieved.
# @param theCenter Point, specifying center of the sphere to find shapes on.
# @param theRadius Radius of the sphere to find shapes on.
- # @param theState The state of the subshapes to find. It can be one of
+ # @param theState The state of the sub-shapes to find. It can be one of
# ST_ON, ST_OUT, ST_ONOUT, ST_IN, ST_ONIN.
# @return List of all found sub-shapes.
#
@@ -2060,7 +2060,7 @@ class geompyDC(GEOM._objref_GEOM_Gen):
# @param theTopRigthPoint Point, specifying top right corner of a quadrangle
# @param theBottomLeftPoint Point, specifying bottom left corner of a quadrangle
# @param theBottomRigthPoint Point, specifying bottom right corner of a quadrangle
- # @param theState The state of the subshapes to find. It can be one of
+ # @param theState The state of the sub-shapes to find. It can be one of
# ST_ON, ST_OUT, ST_ONOUT, ST_IN, ST_ONIN.
# @return List of all found sub-shapes.
#
@@ -2093,7 +2093,7 @@ class geompyDC(GEOM._objref_GEOM_Gen):
# @param theBox Shape for relative comparing.
# @param theShape Shape to find sub-shapes of.
# @param theShapeType Type of sub-shapes to be retrieved.
- # @param theState The state of the subshapes to find. It can be one of
+ # @param theState The state of the sub-shapes to find. It can be one of
# ST_ON, ST_OUT, ST_ONOUT, ST_IN, ST_ONIN.
# @return List of all found sub-shapes.
#
@@ -2119,7 +2119,7 @@ class geompyDC(GEOM._objref_GEOM_Gen):
# @param theCheckShape Shape for relative comparing. It must be a solid.
# @param theShape Shape to find sub-shapes of.
# @param theShapeType Type of sub-shapes to be retrieved.
- # @param theState The state of the subshapes to find. It can be one of
+ # @param theState The state of the sub-shapes to find. It can be one of
# ST_ON, ST_OUT, ST_ONOUT, ST_IN, ST_ONIN.
# @return List of all found sub-shapes.
#
@@ -2264,7 +2264,7 @@ class geompyDC(GEOM._objref_GEOM_Gen):
RaiseIfFailed("GetExistingSubObjects", self.ShapesOp)
return ListObj
- ## Explode a shape on subshapes of a given type.
+ ## Explode a shape on sub-shapes of a given type.
# If the shape itself matches the type, it is also returned.
# @param aShape Shape to be exploded.
# @param aType Type of sub-shapes to be retrieved.
@@ -2277,7 +2277,7 @@ class geompyDC(GEOM._objref_GEOM_Gen):
RaiseIfFailed("SubShapeAll", self.ShapesOp)
return ListObj
- ## Explode a shape on subshapes of a given type.
+ ## Explode a shape on sub-shapes of a given type.
# @param aShape Shape to be exploded.
# @param aType Type of sub-shapes to be retrieved.
# @return List of IDs of sub-shapes.
@@ -2302,7 +2302,7 @@ class geompyDC(GEOM._objref_GEOM_Gen):
anObj = self.GetSubShape(aShape, ListOfIDs)
return anObj
- ## Explode a shape on subshapes of a given type.
+ ## Explode a shape on sub-shapes of a given type.
# Sub-shapes will be sorted by coordinates of their gravity centers.
# If the shape itself matches the type, it is also returned.
# @param aShape Shape to be exploded.
@@ -2316,7 +2316,7 @@ class geompyDC(GEOM._objref_GEOM_Gen):
RaiseIfFailed("SubShapeAllSortedCentres", self.ShapesOp)
return ListObj
- ## Explode a shape on subshapes of a given type.
+ ## Explode a shape on sub-shapes of a given type.
# Sub-shapes will be sorted by coordinates of their gravity centers.
# @param aShape Shape to be exploded.
# @param aType Type of sub-shapes to be retrieved.
@@ -2355,10 +2355,10 @@ class geompyDC(GEOM._objref_GEOM_Gen):
RaiseIfFailed("ExtractSubShapes", self.ShapesOp)
return ListObj
- ## Get a set of sub shapes defined by their unique IDs inside theMainShape
+ ## Get a set of sub-shapes defined by their unique IDs inside theMainShape
# @param theMainShape Main shape.
- # @param theIndices List of unique IDs of sub shapes inside theMainShape.
- # @return List of GEOM_Objects, corresponding to found sub shapes.
+ # @param theIndices List of unique IDs of sub-shapes inside theMainShape.
+ # @return List of GEOM_Objects, corresponding to found sub-shapes.
#
# @ref swig_all_decompose "Example"
def SubShapes(self, aShape, anIDs):
@@ -3692,8 +3692,8 @@ class geompyDC(GEOM._objref_GEOM_Gen):
RaiseIfFailed("GetCentreOfMass", self.MeasuOp)
return anObj
- ## Get a vertex subshape by index depended with orientation.
- # @param theShape Shape to find subshape.
+ ## Get a vertex sub-shape by index depended with orientation.
+ # @param theShape Shape to find sub-shape.
# @param theIndex Index to find vertex by this index (starting from zero)
# @return New GEOM_Object, containing the created vertex.
#
@@ -4151,11 +4151,11 @@ class geompyDC(GEOM._objref_GEOM_Gen):
RaiseIfFailed("GetFaceByNormale", self.BlocksOp)
return anObj
- ## Find all subshapes of type \a theShapeType of the given shape,
+ ## Find all sub-shapes of type \a theShapeType of the given shape,
# which have minimal distance to the given point.
# @param theShape Any shape.
# @param thePoint Point, close to the desired shape.
- # @param theShapeType Defines what kind of subshapes is searched.
+ # @param theShapeType Defines what kind of sub-shapes is searched.
# @param theTolerance The tolerance for distances comparison. All shapes
# with distances to the given point in interval
# [minimal_distance, minimal_distance + theTolerance] will be gathered.
@@ -4345,7 +4345,7 @@ class geompyDC(GEOM._objref_GEOM_Gen):
## @addtogroup l3_groups
## @{
- ## Creates a new group which will store sub shapes of theMainShape
+ ## Creates a new group which will store sub-shapes of theMainShape
# @param theMainShape is a GEOM object on which the group is selected
# @param theShapeType defines a shape type of the group
# @return a newly created GEOM group
@@ -4358,10 +4358,10 @@ class geompyDC(GEOM._objref_GEOM_Gen):
RaiseIfFailed("CreateGroup", self.GroupOp)
return anObj
- ## Adds a sub object with ID theSubShapeId to the group
- # @param theGroup is a GEOM group to which the new sub shape is added
- # @param theSubShapeID is a sub shape ID in the main object.
- # \note Use method GetSubShapeID() to get an unique ID of the sub shape
+ ## Adds a sub-object with ID theSubShapeId to the group
+ # @param theGroup is a GEOM group to which the new sub-shape is added
+ # @param theSubShapeID is a sub-shape ID in the main object.
+ # \note Use method GetSubShapeID() to get an unique ID of the sub-shape
#
# @ref tui_working_with_groups_page "Example"
def AddObject(self,theGroup, theSubShapeID):
@@ -4372,10 +4372,10 @@ class geompyDC(GEOM._objref_GEOM_Gen):
pass
pass
- ## Removes a sub object with ID \a theSubShapeId from the group
- # @param theGroup is a GEOM group from which the new sub shape is removed
- # @param theSubShapeID is a sub shape ID in the main object.
- # \note Use method GetSubShapeID() to get an unique ID of the sub shape
+ ## Removes a sub-object with ID \a theSubShapeId from the group
+ # @param theGroup is a GEOM group from which the new sub-shape is removed
+ # @param theSubShapeID is a sub-shape ID in the main object.
+ # \note Use method GetSubShapeID() to get an unique ID of the sub-shape
#
# @ref tui_working_with_groups_page "Example"
def RemoveObject(self,theGroup, theSubShapeID):
@@ -4385,8 +4385,8 @@ class geompyDC(GEOM._objref_GEOM_Gen):
pass
## Adds to the group all the given shapes. No errors, if some shapes are alredy included.
- # @param theGroup is a GEOM group to which the new sub shapes are added.
- # @param theSubShapes is a list of sub shapes to be added.
+ # @param theGroup is a GEOM group to which the new sub-shapes are added.
+ # @param theSubShapes is a list of sub-shapes to be added.
#
# @ref tui_working_with_groups_page "Example"
def UnionList (self,theGroup, theSubShapes):
@@ -4426,7 +4426,7 @@ class geompyDC(GEOM._objref_GEOM_Gen):
RaiseIfFailed("DifferenceIDs", self.GroupOp)
pass
- ## Returns a list of sub objects ID stored in the group
+ ## Returns a list of sub-objects ID stored in the group
# @param theGroup is a GEOM group for which a list of IDs is requested
#
# @ref swig_GetObjectIDs "Example"
@@ -4436,7 +4436,7 @@ class geompyDC(GEOM._objref_GEOM_Gen):
RaiseIfFailed("GetObjects", self.GroupOp)
return ListIDs
- ## Returns a type of sub objects stored in the group
+ ## Returns a type of sub-objects stored in the group
# @param theGroup is a GEOM group which type is returned.
#
# @ref swig_GetType "Example"
diff --git a/src/GroupGUI/GroupGUI_GroupDlg.cxx b/src/GroupGUI/GroupGUI_GroupDlg.cxx
index 356b9e1a1..d3c7e224a 100644
--- a/src/GroupGUI/GroupGUI_GroupDlg.cxx
+++ b/src/GroupGUI/GroupGUI_GroupDlg.cxx
@@ -474,7 +474,7 @@ void GroupGUI_GroupDlg::SelectionIntoArgument()
}
myMainObj = anObj;
myEditCurrentArgument->setText(GEOMBase::GetName(anObj));
- // activate subshapes selection by default
+ // activate sub-shapes selection by default
myEditCurrentArgument = 0;
activateSelection();
updateState();
@@ -996,7 +996,7 @@ void GroupGUI_GroupDlg::highlightSubShapes()
SALOME_ListIO aSelList;
- // To highlight the selected subshape in Object Browser, if it's already published under the main shape
+ // To highlight the selected sub-shape in Object Browser, if it's already published under the main shape
GEOM::GEOM_ILocalOperations_var aLocOp = getGeomEngine()->GetILocalOperations(getStudyId());
QMap childsMap;
SalomeApp_Study* appStudy = dynamic_cast(app->activeStudy());
diff --git a/src/OperationGUI/OperationGUI_GetShapesOnShapeDlg.cxx b/src/OperationGUI/OperationGUI_GetShapesOnShapeDlg.cxx
index 429c6b663..20bb13117 100644
--- a/src/OperationGUI/OperationGUI_GetShapesOnShapeDlg.cxx
+++ b/src/OperationGUI/OperationGUI_GetShapesOnShapeDlg.cxx
@@ -93,7 +93,7 @@ OperationGUI_GetShapesOnShapeDlg::~OperationGUI_GetShapesOnShapeDlg()
//=================================================================================
void OperationGUI_GetShapesOnShapeDlg::Init()
{
- // type for sub shape selection
+ // type for sub-shape selection
GroupPoints->ComboBox1->addItem(tr("GEOM_RECONSTRUCTION_LIMIT_SOLID"));
// commented by skl for IPAL19949 - finder isn't allowed such type
//GroupPoints->ComboBox1->addItem(tr("GEOM_RECONSTRUCTION_LIMIT_SHELL"));
diff --git a/src/OperationGUI/OperationGUI_GetSharedShapesDlg.cxx b/src/OperationGUI/OperationGUI_GetSharedShapesDlg.cxx
index f37d4c180..c4a06b7d3 100644
--- a/src/OperationGUI/OperationGUI_GetSharedShapesDlg.cxx
+++ b/src/OperationGUI/OperationGUI_GetSharedShapesDlg.cxx
@@ -103,7 +103,7 @@ OperationGUI_GetSharedShapesDlg::~OperationGUI_GetSharedShapesDlg()
//=================================================================================
void OperationGUI_GetSharedShapesDlg::Init()
{
- /* type for sub shape selection */
+ /* type for sub-shape selection */
GroupPoints->ComboBox1->addItem(tr("GEOM_SOLID"));
GroupPoints->ComboBox1->addItem(tr("GEOM_SHELL"));
GroupPoints->ComboBox1->addItem(tr("GEOM_FACE"));
diff --git a/src/OperationGUI/OperationGUI_PartitionDlg.cxx b/src/OperationGUI/OperationGUI_PartitionDlg.cxx
index 005b9adc4..68c545faa 100644
--- a/src/OperationGUI/OperationGUI_PartitionDlg.cxx
+++ b/src/OperationGUI/OperationGUI_PartitionDlg.cxx
@@ -117,7 +117,7 @@ GEOM::ListOfLong OperationGUI_PartitionDlg::GetListMaterials()
//=================================================================================
void OperationGUI_PartitionDlg::Init()
{
- /* type for sub shape selection */
+ /* type for sub-shape selection */
GroupPoints->ComboBox1->addItem( tr( "GEOM_RECONSTRUCTION_LIMIT_SOLID" ) );
GroupPoints->ComboBox1->setItemData(GroupPoints->ComboBox1->count()-1, GEOM::SOLID);
GroupPoints->ComboBox1->addItem( tr( "GEOM_RECONSTRUCTION_LIMIT_SHELL" ) );
diff --git a/src/RepairGUI/RepairGUI_DivideEdgeDlg.cxx b/src/RepairGUI/RepairGUI_DivideEdgeDlg.cxx
index 224856fed..61fd7ed5b 100644
--- a/src/RepairGUI/RepairGUI_DivideEdgeDlg.cxx
+++ b/src/RepairGUI/RepairGUI_DivideEdgeDlg.cxx
@@ -261,7 +261,7 @@ void RepairGUI_DivideEdgeDlg::SelectionIntoArgument()
(SalomeApp_Application*)(SUIT_Session::session()->activeApplication());
anApp->selectionMgr()->GetIndexes( anIO, aMap );
- if ( !aMap.IsEmpty() ) // subshape selection
+ if ( !aMap.IsEmpty() ) // sub-shape selection
{
myIndex = aMap( 1 );
myObject = aSelectedObj;
@@ -273,7 +273,7 @@ void RepairGUI_DivideEdgeDlg::SelectionIntoArgument()
myObject = aSelectedObj;
myEditCurrentArgument->setText( GEOMBase::GetName( myObject ) );
}
- else // face, shell, solid or compound was selected, and NOT its subshape.
+ else // face, shell, solid or compound was selected, and NOT its sub-shape.
{
myIndex = -1;
myObject = GEOM::GEOM_Object::_nil();
diff --git a/src/ShHealOper/ShHealOper_Sewing.cxx b/src/ShHealOper/ShHealOper_Sewing.cxx
index 4710d37b5..a5320584e 100644
--- a/src/ShHealOper/ShHealOper_Sewing.cxx
+++ b/src/ShHealOper/ShHealOper_Sewing.cxx
@@ -119,7 +119,7 @@ Standard_Boolean ShHealOper_Sewing::sewing(const TopTools_SequenceOfShape& theSe
//analysis either sewing was made by changing number of shells
myDone = isSewed(aSewShape);
- //keep modification of the subshapes in the Context.
+ //keep modification of the sub-shapes in the Context.
TopExp_Explorer aExp(myInitShape,TopAbs_FACE);
for( ; aExp.More(); aExp.Next())
myDone = (getModifications( aExp.Current(),aSewing) || myDone);
diff --git a/src/GEOMImpl/GEOMImpl_IBlocksOperations.cxx b/src/GEOMImpl/GEOMImpl_IBlocksOperations.cxx
index 3178b013c..899afc083 100644
--- a/src/GEOMImpl/GEOMImpl_IBlocksOperations.cxx
+++ b/src/GEOMImpl/GEOMImpl_IBlocksOperations.cxx
@@ -1597,7 +1597,7 @@ Handle(GEOM_Object) GEOMImpl_IBlocksOperations::GetShapesNearPoint
}
if (nbEdges == 0) {
- SetErrorCode("Given shape contains no subshapes of requested type");
+ SetErrorCode("Given shape contains no sub-shapes of requested type");
return NULL;
}
@@ -1614,7 +1614,7 @@ Handle(GEOM_Object) GEOMImpl_IBlocksOperations::GetShapesNearPoint
BRepExtrema_DistShapeShape aDistTool (aVert, anEdges(ind));
if (!aDistTool.IsDone()) {
- SetErrorCode("Can not find a distance from the given point to one of subshapes");
+ SetErrorCode("Can not find a distance from the given point to one of sub-shapes");
return NULL;
}
aDistances(ind) = aDistTool.Value();
@@ -1626,7 +1626,7 @@ Handle(GEOM_Object) GEOMImpl_IBlocksOperations::GetShapesNearPoint
}
if (aMinDist < RealLast()) {
// Collect subshapes with distance < (aMinDist + theTolerance)
int nbSubShapes = 0;
TopTools_Array1OfShape aNearShapes (1, nbEdges);
for (ind = 1; ind <= nbEdges; ind++) {
@@ -1636,7 +1636,7 @@ Handle(GEOM_Object) GEOMImpl_IBlocksOperations::GetShapesNearPoint
}
}
- // Add subshape
+ // Add sub-shape
TopTools_IndexedMapOfShape anIndices;
TopExp::MapShapes(aBlockOrComp, anIndices);
Handle(TColStd_HArray1OfInteger) anArray = new TColStd_HArray1OfInteger (1, nbSubShapes);
@@ -3381,7 +3381,7 @@ Handle(TColStd_HSequenceOfTransient) GEOMImpl_IBlocksOperations::Propagate
// Set a GROUP type
aChain->SetType(GEOM_GROUP);
- // Set a sub shape type
+ // Set a sub-shape type
TDF_Label aFreeLabel = aChain->GetFreeLabel();
TDataStd_Integer::Set(aFreeLabel, (Standard_Integer)TopAbs_EDGE);
@@ -1626,7 +1626,7 @@ Handle(GEOM_Object) GEOMImpl_IBlocksOperations::GetShapesNearPoint
}
if (aMinDist < RealLast()) {
- // Collect subshapes with distance < (aMinDist + theTolerance)
+ // Collect sub-shapes with distance < (aMinDist + theTolerance)
int nbSubShapes = 0;
TopTools_Array1OfShape aNearShapes (1, nbEdges);